@@ -3,8 +3,8 @@
   Program:   Image Guided Surgery Software Toolkit
   Module:    $RCSfile: Navigator.h,v $
   Language:  C++
-  Date:      $Date: 2009-06-15 19:09:31 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date: 2010-12-17 22:43:50 $
+  Version:   $Revision: 1.4 $
 
   Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
   See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.
@@ -545,7 +545,7 @@ private:
   {
     igstk::Transform transform;
     igstk::Transform::VectorType translation;
-    for (int i=0; i<3; i++)
+    for (unsigned int i=0; i<3; i++)
       {
       translation[i] = point[i];
       }
@@ -559,7 +559,7 @@ private:
   TransformToPoint( igstk::Transform transform)
   {
     ImageSpatialObjectType::PointType point;
-    for (int i=0; i<3; i++)
+    for (unsigned int i=0; i<3; i++)
       {
       point[i] = transform.GetTranslation()[i];
       }
@@ -593,7 +593,7 @@ private:
   void ReferenceAvailableCallback( const itk::EventObject & event ); 
   void OffOrthogonalResliceCallback( const itk::EventObject & event ); 
   void OrthogonalResliceCallback( const itk::EventObject & event ); 
-  void NullActionCallback(const itk::EventObject & event ){};
+  void NullActionCallback(const itk::EventObject & itkNotUsed(event) ){};
   void OnITKProgressEvent(itk::Object *source, const itk::EventObject &);
 
 };
