@@ -3,8 +3,8 @@
 Program:   Image Guided Surgery Software Toolkit
 Module:    $RCSfile: NeedleBiopsy.cxx,v $
 Language:  C++
-Date:      $Date: 2009-06-12 15:23:31 $
-Version:   $Revision: 1.3 $
+Date:      $Date: 2010-11-16 04:43:41 $
+Version:   $Revision: 1.4 $
 
 Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
   See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.
@@ -164,7 +164,7 @@ NeedleBiopsy::NeedleBiopsy() : m_LogFile()
 
   /** Create image slice representations  */
   m_ImageRepresentation.clear();
-  for (int i=0; i<6; i++)
+  for (unsigned int i=0; i<6; i++)
     {
     ImageRepresentationType::Pointer rep = ImageRepresentationType::New();
     m_ImageRepresentation.push_back( rep );
@@ -1023,7 +1023,7 @@ void NeedleBiopsy::UpdatePath()
   m_Path->AddPoint( point );
 
 
-  for (int i=0; i<4; i++)
+  for (unsigned int i=0; i<4; i++)
     {
     ViewerGroup->m_Views[i]->RequestRemoveObject( m_PathRepresentation[i] );
     m_PathRepresentation[i]->RequestSetTubeObject( NULL );
