@@ -3,8 +3,8 @@
 Program:   Image Guided Surgery Software Toolkit
 Module:    $RCSfile: igstkTreatmentPlan.cxx,v $
 Language:  C++
-Date:      $Date: 2009-01-30 20:49:54 $
-Version:   $Revision: 1.1 $
+Date:      $Date: 2010-11-16 04:43:41 $
+Version:   $Revision: 1.2 $
 
 Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
   See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.
@@ -27,7 +27,7 @@ TreatmentPlan::TreatmentPlan()
   m_TargetPoint.Fill( 10.0 );
   PointType p;
   p.Fill( 0.0 );
-  for (int i=0; i<3; i++)
+  for (unsigned int i=0; i<3; i++)
     {
     m_FiducialPoints.push_back( p );
     }
