@@ -3,8 +3,8 @@
   Program:   Image Guided Surgery Software Toolkit
   Module:    $RCSfile: igstkOpenIGTLinkTrackerConfigurationFileReader.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-06-04 19:49:05 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2010-12-22 20:39:42 $
+  Version:   $Revision: 1.2 $
 
   Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
   See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.
@@ -552,8 +552,8 @@ OpenIGTLinkTrackerConfigurationFileReader::GetDataProcessing()
 }
 
 void  
-OpenIGTLinkTrackerConfigurationFileReader::PrintSelf( std::ostream& os, 
-                                     itk::Indent indent ) const
+OpenIGTLinkTrackerConfigurationFileReader::PrintSelf( std::ostream& itkNotUsed(os), 
+                                     itk::Indent itkNotUsed(indent) ) const
 {
 }
 
