@@ -3,8 +3,8 @@
   Program:   Image Guided Surgery Software Toolkit
   Module:    $RCSfile: main.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-06-08 20:56:31 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2010-12-17 22:43:50 $
+  Version:   $Revision: 1.2 $
 
   Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
   See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.
@@ -19,7 +19,7 @@
 #include "igstkRealTimeClock.h"
 
       
-int main(int argc, char *argv[])
+int main(int , char *[])
 {
   PivotCalibrationFLTKWidgetExample app;
 
