@@ -3,8 +3,8 @@
   Program:   Image Guided Surgery Software Toolkit
   Module:    $RCSfile: igstkFiducialsPlan.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-02-03 15:59:02 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2010-11-16 04:43:41 $
+  Version:   $Revision: 1.2 $
 
   Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
   See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.
@@ -25,7 +25,7 @@ namespace igstk
   {
     PointType p;
     p.Fill( 0.0 );
-    for (int i=0; i<4; i++)
+    for (unsigned int i=0; i<4; i++)
       {
       m_FiducialPoints.push_back( p );
       }
