@@ -3,8 +3,8 @@
   Program:   Image Guided Surgery Software Toolkit
   Module:    $RCSfile: igstkTrackerConfigurationFileReader.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-01-30 20:48:03 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2010-12-14 16:31:33 $
+  Version:   $Revision: 1.2 $
 
   Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
   See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.
@@ -531,8 +531,8 @@ TrackerConfigurationFileReader::GetDataProcessing()
 }
 
 void  
-TrackerConfigurationFileReader::PrintSelf( std::ostream& os, 
-                                     itk::Indent indent ) const
+TrackerConfigurationFileReader::PrintSelf( std::ostream& itkNotUsed(os), 
+                                     itk::Indent itkNotUsed(indent) ) const
 {
 }
 
