@@ -3,8 +3,8 @@
   Program:   Image Guided Surgery Software Toolkit
   Module:    $RCSfile: igstkTrackerController.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-05-21 18:21:13 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2011-02-04 19:02:19 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
   See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.
@@ -30,6 +30,11 @@
 #include "igstkMicronTracker.h"
 #endif
 
+#ifdef IGSTK_USE_Ascension3DGTracker
+#include "igstkAscension3DGTracker.h"
+#endif
+
+
 
 namespace igstk
 { 
@@ -52,6 +57,7 @@ TrackerController::TrackerController() : m_StateMachine( this )
   igstkAddStateMacro( AttemptingToInitializePolarisHybrid );
   igstkAddStateMacro( AttemptingToInitializeAurora );
   igstkAddStateMacro( AttemptingToInitializeMicron );
+  igstkAddStateMacro( AttemptingToInitializeAscension3DG );
   igstkAddStateMacro( AttemptingToInitializeAscension );  
   igstkAddStateMacro( Initialized );
   igstkAddStateMacro( AttemptingToStartTracking );
@@ -66,6 +72,7 @@ TrackerController::TrackerController() : m_StateMachine( this )
   igstkAddInputMacro( AuroraInitialize );
   igstkAddInputMacro( AscensionInitialize );
   igstkAddInputMacro( MicronInitialize );
+  igstkAddInputMacro( Ascension3DGInitialize );
   igstkAddInputMacro( StartTracking );
   igstkAddInputMacro( StopTracking );
   igstkAddInputMacro( Failed  );
@@ -109,6 +116,11 @@ TrackerController::TrackerController() : m_StateMachine( this )
                            MicronInitialize,
                            Idle,
                            ReportInvalidRequest );
+ 
+  igstkAddTransitionMacro( Idle,
+                           Ascension3DGInitialize,
+                           Idle,
+                           ReportInvalidRequest );
     
   igstkAddTransitionMacro( Idle,
                            StartTracking,
@@ -191,6 +203,11 @@ TrackerController::TrackerController() : m_StateMachine( this )
                            AttemptingToInitializeMicron,
                            MicronInitialize );
 
+  igstkAddTransitionMacro( AttemptingToInitialize,
+                           Ascension3DGInitialize,
+                           AttemptingToInitializeAscension3DG,
+                           Ascension3DGInitialize );
+
   igstkAddTransitionMacro( AttemptingToInitialize,
                            TrackerInitialize,
                            Idle,
@@ -281,6 +298,11 @@ TrackerController::TrackerController() : m_StateMachine( this )
                            MicronInitialize,
                            Idle,
                            ReportInvalidRequest );
+ 
+  igstkAddTransitionMacro( AttemptingToInitializePolarisVicra,
+                           Ascension3DGInitialize,
+                           Idle,
+                           ReportInvalidRequest );
     
   igstkAddTransitionMacro( AttemptingToInitializePolarisVicra,
                            StartTracking,
@@ -362,6 +384,11 @@ TrackerController::TrackerController() : m_StateMachine( this )
                            MicronInitialize,
                            Idle,
                            ReportInvalidRequest );
+ 
+  igstkAddTransitionMacro( AttemptingToInitializePolarisHybrid,
+                           Ascension3DGInitialize,
+                           Idle,
+                           ReportInvalidRequest );
     
   igstkAddTransitionMacro( AttemptingToInitializePolarisHybrid,
                            StartTracking,
@@ -443,6 +470,12 @@ TrackerController::TrackerController() : m_StateMachine( this )
                            MicronInitialize,
                            Idle,
                            ReportInvalidRequest );
+ 
+  igstkAddTransitionMacro( AttemptingToInitializeAurora,
+                           Ascension3DGInitialize,
+                           Idle,
+                           ReportInvalidRequest );
+                           
     
   igstkAddTransitionMacro( AttemptingToInitializeAurora,
                            StartTracking,
@@ -525,6 +558,11 @@ TrackerController::TrackerController() : m_StateMachine( this )
                            Idle,
                            ReportInvalidRequest );
     
+  igstkAddTransitionMacro( AttemptingToInitializeAscension,
+                           Ascension3DGInitialize,
+                           Idle,
+                           ReportInvalidRequest );
+ 
   igstkAddTransitionMacro( AttemptingToInitializeAscension,
                            StartTracking,
                            Idle,
@@ -645,7 +683,92 @@ TrackerController::TrackerController() : m_StateMachine( this )
                            SetChildSpatialObject,
                            Idle,
                            ReportInvalidRequest);
+//transitions from AttemptingToInitializeAscension3DG state
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           Failed,
+                           Idle,
+                           ReportInitializationFailure );
+  
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           Succeeded,
+                           Initialized,
+                           ReportInitializationSuccess );
 
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           TrackerInitialize,
+                           Idle,
+                           ReportInvalidRequest );
+
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           PolarisVicraInitialize,
+                           Idle,
+                           ReportInvalidRequest );
+
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           PolarisHybridInitialize,
+                           Idle,
+                           ReportInvalidRequest );
+
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           AuroraInitialize,
+                           Idle,
+                           ReportInvalidRequest );
+
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           AscensionInitialize,
+                           Idle,
+                           ReportInvalidRequest );
+  
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           MicronInitialize,
+                           Idle,
+                           ReportInvalidRequest );
+
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           Ascension3DGInitialize,
+                           Idle,
+                           ReportInvalidRequest );
+                           
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           StartTracking,
+                           Idle,
+                           ReportInvalidRequest );
+  
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           StopTracking,
+                           Idle,
+                           ReportInvalidRequest );
+
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           CloseCommunication,
+                           Idle,
+                           ReportInvalidRequest );
+
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           GetTools,
+                           Idle,
+                           ReportInvalidRequest );
+  
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           GetTool,
+                           Idle,
+                           ReportInvalidRequest );
+
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           GetReferenceTool,
+                           Idle,
+                           ReportInvalidRequest);
+
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           SetParentSpatialObject,
+                           Idle,
+                           ReportInvalidRequest);
+
+  igstkAddTransitionMacro( AttemptingToInitializeAscension3DG,
+                           SetChildSpatialObject,
+                           Idle,
+                           ReportInvalidRequest);
+ 
   //transitions from Initialized state
   igstkAddTransitionMacro( Initialized,
                            GetTools,
@@ -717,6 +840,11 @@ TrackerController::TrackerController() : m_StateMachine( this )
                            Initialized,
                            ReportInvalidRequest );
 
+ igstkAddTransitionMacro(  Initialized,
+                           Ascension3DGInitialize,
+                           Initialized,
+                           ReportInvalidRequest );
+                           
   igstkAddTransitionMacro( Initialized,
                            Failed,
                            Initialized,
@@ -767,7 +895,12 @@ TrackerController::TrackerController() : m_StateMachine( this )
                            MicronInitialize,
                            AttemptingToStartTracking,
                            ReportInvalidRequest );
-  
+
+  igstkAddTransitionMacro( AttemptingToStartTracking,
+                           Ascension3DGInitialize,
+                           AttemptingToStartTracking,
+                           ReportInvalidRequest );
+ 
   igstkAddTransitionMacro( AttemptingToStartTracking,
                            StartTracking,
                            AttemptingToStartTracking,
@@ -844,6 +977,11 @@ TrackerController::TrackerController() : m_StateMachine( this )
                            Tracking,
                            ReportInvalidRequest );
 
+  igstkAddTransitionMacro( Tracking,
+                           Ascension3DGInitialize,
+                           Tracking,
+                           ReportInvalidRequest );
+                           
   igstkAddTransitionMacro( Tracking,
                            StartTracking,
                            Tracking,
@@ -930,6 +1068,11 @@ TrackerController::TrackerController() : m_StateMachine( this )
                            AttemptingToStopTracking,
                            ReportInvalidRequest );
 
+  igstkAddTransitionMacro( AttemptingToStopTracking,
+                           Ascension3DGInitialize,
+                           AttemptingToStopTracking,
+                           ReportInvalidRequest );
+                           
   igstkAddTransitionMacro( AttemptingToStopTracking,
                            StartTracking,
                            AttemptingToStopTracking,
@@ -1012,6 +1155,11 @@ TrackerController::TrackerController() : m_StateMachine( this )
                            AttemptingToCloseCommunication,
                            ReportInvalidRequest );
 
+  igstkAddTransitionMacro( AttemptingToCloseCommunication,
+                           Ascension3DGInitialize,
+                           AttemptingToCloseCommunication,
+                           ReportInvalidRequest );
+                           
   igstkAddTransitionMacro( AttemptingToCloseCommunication,
                            StartTracking,
                            AttemptingToCloseCommunication,
@@ -1213,6 +1361,15 @@ TrackerController::TrackerInitializeProcessing()
       igstkPushInputMacro( MicronInitialize );
       }
    #endif
+   #ifdef IGSTK_USE_Ascension3DGTracker
+    else if( dynamic_cast<Ascension3DGTrackerConfiguration *>
+      ( this->m_TmpTrackerConfiguration ) )
+      {
+      this->m_TrackerConfiguration = m_TmpTrackerConfiguration;
+      igstkPushInputMacro( Ascension3DGInitialize );
+      }
+   #endif
+ 
     else
       {
       this->m_ErrorMessage = 
@@ -1458,8 +1615,6 @@ TrackerController::PolarisVicraInitializeProcessing()
         currentTool->RemoveObserver( observerID ); 
         if( attachErrorObserver->GotToolAttachError() )
           {
-          this->m_ErrorMessage = "Failed to connect tool to tracker.";
-          this->m_SerialCommunication->CloseCommunication();
           igstkPushInputMacro( Failed );
           this->m_StateMachine.ProcessInputs();
           return;
@@ -1483,8 +1638,6 @@ TrackerController::PolarisVicraInitializeProcessing()
         currentTool->RemoveObserver( observerID );
         if( attachErrorObserver->GotToolAttachError() )
           {
-          this->m_ErrorMessage = "Failed to connect tool to tracker.";
-          this->m_SerialCommunication->CloseCommunication();
           igstkPushInputMacro( Failed );
           this->m_StateMachine.ProcessInputs();
           return;
@@ -1569,8 +1722,6 @@ TrackerController::PolarisHybridInitializeProcessing()
         trackerTool->RemoveObserver( observerID ); 
         if( attachErrorObserver->GotToolAttachError() )
           {
-          this->m_ErrorMessage = "Failed to connect tool to tracker.";
-          this->m_SerialCommunication->CloseCommunication();
           igstkPushInputMacro( Failed );
           this->m_StateMachine.ProcessInputs();
           return;
@@ -1602,8 +1753,6 @@ TrackerController::PolarisHybridInitializeProcessing()
         trackerTool->RemoveObserver( observerID ); 
         if( attachErrorObserver->GotToolAttachError() )
           {
-          this->m_ErrorMessage = "Failed to connect tool to tracker.";
-          this->m_SerialCommunication->CloseCommunication();
           igstkPushInputMacro( Failed );
           this->m_StateMachine.ProcessInputs();
           return;
@@ -1729,8 +1878,6 @@ TrackerController::AscensionInitializeProcessing()
         currentTool->RemoveObserver( observerID ); 
         if( attachErrorObserver->GotToolAttachError() )
           {
-          this->m_ErrorMessage = "Failed to connect tool to tracker.";
-          this->m_SerialCommunication->CloseCommunication();
           igstkPushInputMacro( Failed );
           this->m_StateMachine.ProcessInputs();
           return;
@@ -1753,8 +1900,6 @@ TrackerController::AscensionInitializeProcessing()
         currentTool->RemoveObserver( observerID ); 
         if( attachErrorObserver->GotToolAttachError() )
           {
-          this->m_ErrorMessage = "Failed to connect tool to tracker.";
-          this->m_SerialCommunication->CloseCommunication();
           igstkPushInputMacro( Failed );
           this->m_StateMachine.ProcessInputs();
           return;
@@ -1829,8 +1974,6 @@ TrackerController::AuroraInitializeProcessing()
         currentTool->RemoveObserver( observerID ); 
         if( attachErrorObserver->GotToolAttachError() )
           {
-          this->m_ErrorMessage = "Failed to connect tool to tracker.";
-          this->m_SerialCommunication->CloseCommunication();
           igstkPushInputMacro( Failed );
           this->m_StateMachine.ProcessInputs();
           return;
@@ -1853,8 +1996,6 @@ TrackerController::AuroraInitializeProcessing()
         currentTool->RequestAttachToTracker( tracker );
         if( attachErrorObserver->GotToolAttachError() )
           {
-          this->m_ErrorMessage = "Failed to connect tool to tracker.";
-          this->m_SerialCommunication->CloseCommunication();
           igstkPushInputMacro( Failed );
           this->m_StateMachine.ProcessInputs();
           return;
@@ -1885,6 +2026,23 @@ MicronTrackerTool::Pointer TrackerController::InitializeMicronTool(
 
 #endif
 
+#ifdef IGSTK_USE_Ascension3DGTracker
+
+Ascension3DGTrackerTool::Pointer TrackerController::InitializeAscension3DGTool(
+    const Ascension3DGToolConfiguration *toolConfiguration )
+{
+  Ascension3DGTrackerTool::Pointer trackerTool = Ascension3DGTrackerTool::New();
+ 
+  trackerTool->SetCalibrationTransform( 
+    toolConfiguration->GetCalibrationTransform() );
+  trackerTool->RequestSetPortNumber(toolConfiguration->GetPortNumber());
+  trackerTool->RequestConfigure();
+  return trackerTool;
+}
+
+#endif
+
+
 
 void TrackerController::MicronInitializeProcessing()
 {
@@ -1948,7 +2106,6 @@ void TrackerController::MicronInitializeProcessing()
       trackerTool->RemoveObserver( observerID ); 
       if( attachErrorObserver->GotToolAttachError() )
         {
-        this->m_ErrorMessage = "Failed to connect tool to tracker.";
         igstkPushInputMacro( Failed );
         this->m_StateMachine.ProcessInputs();
         return;
@@ -1971,7 +2128,96 @@ void TrackerController::MicronInitializeProcessing()
       trackerTool->RequestAttachToTracker( tracker );
       if( attachErrorObserver->GotToolAttachError() )
         {
-        this->m_ErrorMessage = "Failed to connect tool to tracker.";
+        igstkPushInputMacro( Failed );
+        this->m_StateMachine.ProcessInputs();
+        return;
+        }
+      tracker->RequestSetReferenceTool( trackerTool );
+      }
+    igstkPushInputMacro( Succeeded );
+    }
+  this->m_StateMachine.ProcessInputs();
+#else
+  igstkPushInputMacro( Failed );
+  this->m_StateMachine.ProcessInputs();
+#endif
+}
+
+void TrackerController::Ascension3DGInitializeProcessing()
+{
+#ifdef IGSTK_USE_Ascension3DGTracker
+                  //create tracker
+  igstk::Ascension3DGTracker::Pointer tracker = igstk::Ascension3DGTracker::New();
+  this->m_Tracker = tracker; 
+                 //don't need to observe this for errors because the 
+                 //configuration class ensures that the frequency is valid
+  tracker->RequestSetFrequency( this->m_TrackerConfiguration->GetFrequency() );
+
+  Ascension3DGTrackerConfiguration *trackerConfiguration =
+    dynamic_cast<Ascension3DGTrackerConfiguration *>( this->m_TrackerConfiguration );
+
+  unsigned long observerID = tracker->AddObserver( IGSTKErrorEvent(),
+                                                   this->m_ErrorObserver );
+  tracker->RequestOpen();
+  tracker->RemoveObserver(observerID);
+  
+  if( this->m_ErrorObserver->ErrorOccured() )
+    {
+    this->m_ErrorObserver->GetErrorMessage( this->m_ErrorMessage );
+    this->m_ErrorObserver->ClearError();
+    igstkPushInputMacro( Failed );
+    }
+  else   //attach the tools and start communication 
+    {
+    ToolAttachErrorObserver::Pointer attachErrorObserver = 
+      ToolAttachErrorObserver::New();
+    std::map<std::string, TrackerToolConfiguration *> toolConfigurations = 
+        this->m_TrackerConfiguration->m_TrackerToolList;
+                          //attach tools
+    std::map<std::string, TrackerToolConfiguration *>::const_iterator it;
+    std::map<std::string, TrackerToolConfiguration *>::const_iterator 
+      toolConfigEnd = toolConfigurations.end();
+    TrackerTool::Pointer trackerTool;
+    Ascension3DGToolConfiguration * currentToolConfig;
+
+    for(it = toolConfigurations.begin(); it != toolConfigEnd; it++)
+      {
+      currentToolConfig = static_cast<Ascension3DGToolConfiguration *>(it->second);
+
+      trackerTool = InitializeAscension3DGTool( currentToolConfig );
+      this->m_Tools.insert(
+          std::pair<std::string, TrackerTool::Pointer>( it->first, 
+                                                        trackerTool ) );
+
+      unsigned long observerID = trackerTool->AddObserver( 
+        TrackerToolAttachmentToTrackerErrorEvent(),
+        attachErrorObserver );
+      trackerTool->RequestAttachToTracker( tracker );
+      trackerTool->RemoveObserver( observerID ); 
+      if( attachErrorObserver->GotToolAttachError() )
+        {
+        igstkPushInputMacro( Failed );
+        this->m_StateMachine.ProcessInputs();
+        return;
+        }
+      }
+                      //add the reference if we have one
+    TrackerToolConfiguration* referenceToolConfiguration = 
+      this->m_TrackerConfiguration->m_ReferenceTool;
+    if( referenceToolConfiguration )
+      {
+      currentToolConfig = 
+        static_cast<Ascension3DGToolConfiguration *>( referenceToolConfiguration );
+
+      trackerTool = InitializeAscension3DGTool( currentToolConfig );   
+      this->m_ReferenceTool = trackerTool;
+
+      trackerTool->AddObserver( 
+        TrackerToolAttachmentToTrackerErrorEvent(),
+        attachErrorObserver );      
+      trackerTool->RequestAttachToTracker( tracker );
+      if( attachErrorObserver->GotToolAttachError() )
+        {
         igstkPushInputMacro( Failed );
         this->m_StateMachine.ProcessInputs();
         return;
@@ -2203,7 +2449,7 @@ TrackerController::ErrorObserver::ErrorObserver() : m_ErrorOccured( false )
 
 void 
 TrackerController::ErrorObserver::Execute( 
-  const itk::Object *caller, 
+  const itk::Object * itkNotUsed(caller), 
   const itk::EventObject & event ) throw (std::exception)
 {
   std::map<std::string,std::string>::iterator it;
@@ -2238,7 +2484,7 @@ TrackerController::TrackerUpdateObserver::SetParent( TrackerController *parent )
 
 void
 TrackerController::TrackerUpdateObserver::Execute( 
-  const itk::Object *caller, 
+  const itk::Object * itkNotUsed(caller), 
   const itk::EventObject & event ) throw ( std::exception )
 {
   if( igstk::TrackerUpdateStatusEvent().CheckEvent( &event ) ||
