@@ -3,8 +3,8 @@
   Program:   Image Guided Surgery Software Toolkit
   Module:    $RCSfile: TrackingVolumeViewer.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-04-27 17:36:46 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date: 2011-02-04 19:53:17 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
   See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.
@@ -31,6 +31,7 @@
 
 #include "igstkAuroraConfigurationXMLFileReader.h"
 #include "igstkAscensionConfigurationXMLFileReader.h"
+#include "igstkAscension3DGConfigurationXMLFileReader.h"
 #include "igstkPolarisVicraConfigurationXMLFileReader.h"
 #include "igstkPolarisSpectraConfigurationXMLFileReader.h"
 #include "igstkPolarisHybridConfigurationXMLFileReader.h"
@@ -484,21 +485,23 @@ void TrackingVolumeViewer::ConfigureTrackerProcessing()
       return;
   }
 
-  const unsigned int NUM_TRACKER_TYPES = 6;
+  const unsigned int NUM_TRACKER_TYPES = 7;
   igstk::TrackerConfigurationXMLFileReaderBase::Pointer
-       trackerCofigurationXMLReaders[NUM_TRACKER_TYPES];
-  trackerCofigurationXMLReaders[0] =
+       trackerConfigurationXMLReaders[NUM_TRACKER_TYPES];
+  trackerConfigurationXMLReaders[0] =
        igstk::PolarisVicraConfigurationXMLFileReader::New();
-  trackerCofigurationXMLReaders[1] =
+  trackerConfigurationXMLReaders[1] =
        igstk::PolarisSpectraConfigurationXMLFileReader::New();
-  trackerCofigurationXMLReaders[2] =
+  trackerConfigurationXMLReaders[2] =
        igstk::PolarisHybridConfigurationXMLFileReader::New();
-  trackerCofigurationXMLReaders[3] =
+  trackerConfigurationXMLReaders[3] =
        igstk::AuroraConfigurationXMLFileReader::New();
-  trackerCofigurationXMLReaders[4] =
+  trackerConfigurationXMLReaders[4] =
        igstk::MicronConfigurationXMLFileReader::New();
-  trackerCofigurationXMLReaders[5] =
+  trackerConfigurationXMLReaders[5] =
        igstk::AscensionConfigurationXMLFileReader::New();
+  trackerConfigurationXMLReaders[6] = 
+    igstk::Ascension3DGConfigurationXMLFileReader::New();
 
   igstk::TrackerConfigurationFileReader::Pointer trackerConfigReader =
         igstk::TrackerConfigurationFileReader::New();
@@ -528,7 +531,7 @@ void TrackingVolumeViewer::ConfigureTrackerProcessing()
   {
    //setting the xml reader always succeeds so I don't
    //observe the success event
-   trackerConfigReader->RequestSetReader( trackerCofigurationXMLReaders[i] );
+   trackerConfigReader->RequestSetReader( trackerConfigurationXMLReaders[i] );
 
    trackerConfigReader->RequestRead();
 
@@ -1219,7 +1222,7 @@ void TrackingVolumeViewer::TrackerControllerObserver::Execute( const itk::Object
 }
   
 void 
-TrackingVolumeViewer::TrackerControllerObserver::Execute( itk::Object *caller, 
+TrackingVolumeViewer::TrackerControllerObserver::Execute( itk::Object * itkNotUsed(caller), 
                                                              const itk::EventObject & event )
 {
   const igstk::TrackerController::InitializeErrorEvent *evt1a =
@@ -1292,6 +1295,6 @@ TrackingVolumeViewer::ReportError( const std::string &message )
 void
 TrackingVolumeViewer::ReportError( const char *message )
 {
-  fl_alert( message );
+  fl_alert("%s\n", message );
   fl_beep( FL_BEEP_ERROR );
 }
