@@ -3,8 +3,8 @@
   Program:   Image Guided Surgery Software Toolkit
   Module:    $RCSfile: igstkMacros.h,v $
   Language:  C++
-  Date:      $Date: 2008-06-29 13:37:53 $
-  Version:   $Revision: 1.47 $
+  Date:      $Date: 2010-11-17 18:00:21 $
+  Version:   $Revision: 1.50 $
 
   Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
   See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.
@@ -47,7 +47,7 @@ namespace igstk
     {  \
     if (this->GetLogger()->ShouldBuildMessage( ::igstk::Logger::x ) ) \
       { \
-      ::itk::OStringStream message; \
+      std::ostringstream message; \
       message << y; \
       this->GetLogger()->Write(::itk::Logger::x, message.str()); \
       } \
@@ -64,7 +64,7 @@ namespace igstk
     {  \
     if (obj->GetLogger()->ShouldBuildMessage( ::igstk::Logger::x ) ) \
       { \
-      ::itk::OStringStream message; \
+      std::ostringstream message; \
       message << y; \
       obj->GetLogger()->Write(::itk::Logger::x, message.str()); \
       } \
@@ -81,7 +81,7 @@ namespace igstk
     {  \
     if (logger->ShouldBuildMessage( ::igstk::Logger::x )) \
       { \
-      ::itk::OStringStream message; \
+      std::ostringstream message; \
       message << y; \
       logger->Write(::itk::Logger::x, message.str()); \
       } \
@@ -399,6 +399,7 @@ public:\
         m_GotObject = true;\
         }\
       }\
+    (void) caller;\
     }\
   bool Got##name() const\
     {\
@@ -452,6 +453,7 @@ public:\
         m_GotObject = true;\
         }\
       }\
+    (void) caller;\
     }\
   bool Got##name() const\
     {\
@@ -505,6 +507,7 @@ public:\
         m_GotObject = true;\
         }\
       }\
+    (void) caller;\
     }\
   bool Got##name() const\
     {\
