@@ -3,8 +3,8 @@
   Program:   Image Guided Surgery Software Toolkit
   Module:    $RCSfile: igstkMicronTracker.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-06-18 20:05:14 $
-  Version:   $Revision: 1.13 $
+  Date:      $Date: 2011-01-18 21:40:17 $
+  Version:   $Revision: 1.17 $
 
   Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
   See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.
@@ -172,7 +172,7 @@ void MicronTracker::CreateErrorCodeList()
 std::string
 MicronTracker::GetErrorDescription( unsigned int code )
 {
-  if ( code >= 0 && code <= 55 )
+  if ( code <= 55 )
     {
     return MicronTracker::m_ErrorCodeContainer[code];
     }
@@ -615,7 +615,8 @@ MicronTracker::ResultType MicronTracker::InternalThreadedUpdateStatus( void )
   for(unsigned int markerNum = 1;
       markerNum <= markersCollectionCount; markerNum++)
     {
-    Marker * marker = new Marker(markersCollection->itemI(markerNum));
+    MTMarker::Marker * marker;
+    marker = new MTMarker::Marker(markersCollection->itemI(markerNum));
     if (marker->wasIdentified(this->m_SelectedCamera) )
       {
       //Get postion and pose information
