@@ -3,8 +3,8 @@
   Program:   Image Guided Surgery Software Toolkit
   Module:    $RCSfile: igstkPivotCalibration.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-06-15 20:57:58 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2011-01-18 21:40:17 $
+  Version:   $Revision: 1.10 $
 
   Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
   See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.
@@ -381,8 +381,9 @@ PivotCalibration::ComputeCalibrationProcessing()
 
 
 void 
-PivotCalibration::AcquireTransformsAndCalibrate(itk::Object *caller, 
-                                                const itk::EventObject & event)
+PivotCalibration::AcquireTransformsAndCalibrate(
+                                              itk::Object * itkNotUsed(caller),
+                                   const itk::EventObject & itkNotUsed(event) )
 {  
   //got all the transformations we need for calibration
   if( this->m_Transforms.size() == this->m_RequiredNumberOfTransformations )
@@ -521,7 +522,7 @@ PivotCalibration::ErrorObserver::ErrorObserver() : m_ErrorOccured(false)
 }
 
 void 
-PivotCalibration::ErrorObserver::Execute(const itk::Object *caller, 
+PivotCalibration::ErrorObserver::Execute(const itk::Object * itkNotUsed(caller),
                           const itk::EventObject & event) throw (std::exception)
 {
   std::map<std::string,std::string>::iterator it;
