@@ -3,8 +3,8 @@
   Program:   Image Guided Surgery Software Toolkit
   Module:    $RCSfile: igstkImageResliceObjectRepresentationFltkTest3.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-02-06 11:17:06 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2011-02-09 10:15:40 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
   See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.
@@ -285,6 +285,13 @@ int igstkImageResliceObjectRepresentationFltkTest3( int argc , char * argv [] )
   imageResliceRepresentation->SetWindowLevel( 1559, -244 );
   imageResliceRepresentation->RequestSetImageSpatialObject( imageSpatialObject );
   
+  // code coverage
+  imageResliceRepresentation->SetRestrictPlaneToVolume(0);
+
+  imageResliceRepresentation->SetTextureInterpolate(0);
+
+  imageResliceRepresentation->SetResliceInterpolate(0);
+
   igstk::Transform toolTransform;
   igstk::Transform::VectorType    translation;
   igstk::Transform::VersorType    rotation;
