@@ -3,8 +3,8 @@
   Program:   Image Guided Surgery Software Toolkit
   Module:    $RCSfile: igstkNDICommandInterpreterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-03-18 20:56:04 $
-  Version:   $Revision: 1.26 $
+  Date:      $Date: 2010-12-14 16:31:33 $
+  Version:   $Revision: 1.27 $
 
   Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
   See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.
@@ -56,7 +56,7 @@ public:
     Execute( (const itk::Object *)caller, event);
     }
 
-  void Execute(const itk::Object * object, const itk::EventObject & event)
+  void Execute(const itk::Object * itkNotUsed(object), const itk::EventObject & event)
     {
     const igstk::NDIErrorEvent * ndiEvent = 
       dynamic_cast< const igstk::NDIErrorEvent * >( &event );
