@@ -3,8 +3,8 @@
   Program:   Image Guided Surgery Software Toolkit
   Module:    $RCSfile: igstkStateMachineExportTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-06-19 13:20:40 $
-  Version:   $Revision: 1.30 $
+  Date:      $Date: 2011-02-04 19:43:02 $
+  Version:   $Revision: 1.33 $
 
   Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
   See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.
@@ -72,6 +72,10 @@
 #include "igstkView3D.h"
 #include "igstkCoordinateSystemDelegator.h"
 
+#include "igstkPETImageReader.h"
+#include "igstkPETImageSpatialObject.h"
+#include "igstkPETImageSpatialObjectRepresentation.h"
+
 #include "igstkReslicerPlaneSpatialObject.h"
 #include "igstkImageResliceObjectRepresentation.h"
 #include "igstkMeshResliceObjectRepresentation.h"
@@ -81,6 +85,12 @@
 #include "igstkMicronTrackerTool.h"
 #endif
 
+#if defined(IGSTK_USE_Ascension3DGTracker)
+#include "igstkAscension3DGTracker.h"
+#include "igstkAscension3DGTrackerTool.h"
+#endif
+
+
 #if defined(IGSTK_USE_FLTK)
 #include "igstkFLTKWidget.h"
 #endif
@@ -220,20 +230,20 @@ protected:
     }
 
   ResultType
-  VerifyTrackerToolInformation( const TrackerToolType * trackerTool )
+  VerifyTrackerToolInformation( const TrackerToolType * itkNotUsed(trackerTool) )
     {
     return SUCCESS;
     }
 
   ResultType
-  AddTrackerToolToInternalDataContainers( const TrackerToolType * trackerTool )
+  AddTrackerToolToInternalDataContainers( const TrackerToolType * itkNotUsed(trackerTool) )
     {
     return SUCCESS;
     }
 
   ResultType
   RemoveTrackerToolFromInternalDataContainers(
-    const TrackerToolType * trackerTool )
+    const TrackerToolType * itkNotUsed(trackerTool) )
     {
     return SUCCESS;
     }
@@ -465,6 +475,13 @@ int main( int argc, char * argv [] )
   igstkTestExportStateMachine1( igstk::MR3DImageToUS3DImageRegistration,
                                                    outputDirectory, skipLoops );
 
+  igstkTestExportStateMachine1( igstk::PETImageReader, outputDirectory,
+                                                                    skipLoops );
+  igstkTestExportStateMachine1( igstk::PETImageSpatialObject, outputDirectory,
+                                                                   skipLoops );
+  igstkTestExportStateMachine1( igstk::PETImageSpatialObjectRepresentation, outputDirectory,
+                                                                    skipLoops );
+ 
   igstkTestExportStateMachine1( igstk::View, outputDirectory, skipLoops );
   igstkTestExportStateMachine1( igstk::View2D, outputDirectory, skipLoops );
   igstkTestExportStateMachine1( igstk::View3D, outputDirectory, skipLoops );
@@ -511,5 +528,14 @@ int main( int argc, char * argv [] )
                                 outputDirectory, skipLoops );
 #endif
 
+#if defined(IGSTK_USE_Ascension3DGTracker)
+  igstkTestExportStateMachine1( igstk::Ascension3DGTracker, 
+                                outputDirectory, skipLoops );
+
+  igstkTestExportStateMachine1( igstk::Ascension3DGTracker, 
+                                outputDirectory, skipLoops );
+#endif
+
+
   return EXIT_SUCCESS;
 }
