@@ -361,12 +361,14 @@ int igstkToolProjectionSpatialObjectQtTest( int argc , char * argv [] )
   ToolProjectionType::Pointer toolProjection = ToolProjectionType::New();
   toolProjection->SetSize(150);
   toolProjection->RequestSetTransformAndParent( identity, worldReference );
+  toolProjection->Print(std::cout);
 
   ToolProjectionRepresentationType::Pointer 
             toolProjectionRepresentation = ToolProjectionRepresentationType::New();
   toolProjectionRepresentation->RequestSetToolProjectionObject( toolProjection );
   toolProjectionRepresentation->RequestSetReslicePlaneSpatialObject( reslicerPlaneSpatialObject );
   toolProjectionRepresentation->SetColor( 1,1,0 );
+  toolProjectionRepresentation->Print(std::cout);
 
   // important: we do not set the view as child of the reslicer plane yet 
   //view2D->RequestDetachFromParent();
