@@ -3,8 +3,8 @@
   Program:   Image Guided Surgery Software Toolkit
   Module:    $RCSfile: igstkTransductionMacroTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-02-12 01:20:23 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2010-12-14 16:31:34 $
+  Version:   $Revision: 1.2 $
 
   Copyright (c) ISC  Insight Software Consortium.  All rights reserved.
   See IGSTKCopyright.txt or http://www.igstk.org/copyright.htm for details.
@@ -26,7 +26,7 @@ namespace TransductionMacroTest
 }
 
 
-int igstkTransductionMacroTest( int argc, char* argv[] )
+int igstkTransductionMacroTest( int , char* [] )
 {
 
  
