@@ -3,8 +3,8 @@
 *     Micron Tracker: Example C++ wrapper and Multi-platform demo
 *   
 *     Written by: 
-*     Shahram Izadyar, Robarts Research Institute - London- Ontario , www.robarts.ca
-*     Claudio Gatti, Claron Technology - Toronto -Ontario, www.clarontech.com
+*      Shahram Izadyar, Robarts Research Institute - London- Ontario , www.robarts.ca
+*      Claudio Gatti, Ahmad Kolahi, Claron Technology - Toronto -Ontario, www.clarontech.com
 *
 *     Copyright Claron Technology 2000-2003
 *
@@ -14,6 +14,8 @@
 
 #include "MTC.h"
 
+namespace MTCollection
+{
 class Collection
 {
 public:
@@ -32,5 +34,6 @@ private:
   int m_handle;
   bool ownedByMe;
 };
+};
 
 #endif
