@@ -3,8 +3,8 @@
 *     Micron Tracker: Example C++ wrapper and Multi-platform demo
 *   
 *     Written by: 
-*     Shahram Izadyar, Robarts Research Institute - London- Ontario , www.robarts.ca
-*     Claudio Gatti, Claron Technology - Toronto -Ontario, www.clarontech.com
+*      Shahram Izadyar, Robarts Research Institute - London- Ontario , www.robarts.ca
+*      Claudio Gatti, Ahmad Kolahi, Claron Technology - Toronto -Ontario, www.clarontech.com
 *
 *     Copyright Claron Technology 2000-2003
 *
@@ -13,11 +13,14 @@
 #define __FACET_H__
 
 #include "MTC.h"
+#include <cstdlib>
 #include "MCamera.h"
 #include "Vector.h"
 #include "Collection.h"
 #include "Xform3D.h"
 #include <iostream>
+using namespace MTCollection;
+
 
 class Facet
 {
@@ -25,10 +28,10 @@ public:
   Facet(int h =0);
   ~Facet();
   inline int getHandle(){ return m_handle; };
-  int getXpoints( MCamera *cam, double *result2x2x2x2); //[LV/SV][L/R][base/head][X/Y]
+  int getXpoints( MCamera *cam, double *result2x3x2x2); //[LV/SV][L/R/M][base/head][X/Y]
   vector<Vector *> IdentifiedVectors();
   vector<Vector *> TemplateVectors();
-  bool setVectorsFromSample(vector<Collection*> &sampledVectorSets, string &outCompletionExplanation , double maxSampleErrorAllowedMM = 2.0);
+  bool setVectorsFromSample(vector<MTCollection::Collection*> &sampledVectorSets, string &outCompletionExplanation , double maxSampleErrorAllowedMM = 2.0);
   bool validateTemplate(double positionToleranceMM, string outCompletionString = NULL);
   bool identify(MCamera* cam, vector<Vector*> vectorSet, double positionToleranceMM);
   Xform3D* getFacet2CameraXf(MCamera* cam);
