@@ -3,8 +3,8 @@
 *     Micron Tracker: Example C++ wrapper and Multi-platform demo
 *   
 *     Written by: 
-*     Shahram Izadyar, Robarts Research Institute - London- Ontario , www.robarts.ca
-*     Claudio Gatti, Claron Technology - Toronto -Ontario, www.clarontech.com
+*      Shahram Izadyar, Robarts Research Institute - London- Ontario , www.robarts.ca
+*      Claudio Gatti, Ahmad Kolahi, Claron Technology - Toronto -Ontario, www.clarontech.com
 *
 *     Copyright Claron Technology 2000-2003
 *
@@ -13,12 +13,17 @@
 #define __MARKER_H__
 
 #include "MTC.h"
+//#include <cstdlib>
 #include "Collection.h"
 #include "MCamera.h"
 #include "Facet.h"
 #include "Xform3D.h"
 #include "Persistence.h"
+using namespace MTCollection;
 
+
+namespace MTMarker
+{
 class Marker
 {
 public:
@@ -27,7 +32,7 @@ public:
   inline int getHandle(){ return m_handle; };
 
   int getTemplateFacets();
-  int restoreTemplate(int persistenceHandle, char* name);
+  int restoreTemplate(int persistenceHandle, const char* name);
   
   char* getName();
   void setName(char* name);
@@ -39,7 +44,7 @@ public:
    // double getJitterFilteringFraction();
   int addTemplateFacet(Facet* newFacet, Xform3D* facet1ToNewFacetXf);
   bool validateTemplate(double positionToleranceMM, string complString);
-  int storeTemplate(Persistence* p, char* name);
+  int storeTemplate(Persistence* p, const char* name);
 
 private:
   int m_handle;
@@ -47,5 +52,6 @@ private:
   char m_MarkerName[400];
 
 };
+};
 
 #endif
